@@ -12,7 +12,7 @@
 #define _BONOBO_CANVAS_COMPONENT_H_
 
 #include <libgnome/gnome-defs.h>
-#include <bonobo/bonobo-object.h>
+#include <bonobo/bonobo-xobject.h>
 
 BEGIN_GNOME_DECLS
  
@@ -25,27 +25,26 @@ BEGIN_GNOME_DECLS
 typedef struct _BonoboCanvasComponentPrivate BonoboCanvasComponentPrivate;
 
 typedef struct {
-	BonoboObject base;
+	BonoboXObject base;
 	BonoboCanvasComponentPrivate *priv;
 } BonoboCanvasComponent;
 
 typedef struct {
-	BonoboObjectClass parent_class;
+	BonoboXObjectClass parent_class;
+	
+	POA_Bonobo_Canvas_Component__epv epv;
 
-	/*
-	 * Signals
-	 */
-	 void (*set_bounds) (BonoboCanvasComponent *component,
-			     Bonobo_Canvas_DRect *bbox,
-			     CORBA_Environment *ev);
-
-	 gboolean (*event) (BonoboCanvasComponent *component, GdkEvent *event);
+	/* Signals */
+	void (*set_bounds) (BonoboCanvasComponent *component,
+			    Bonobo_Canvas_DRect   *bbox,
+			    CORBA_Environment     *ev);
+	
+	gboolean (*event)  (BonoboCanvasComponent *component,
+			    GdkEvent              *event);
 } BonoboCanvasComponentClass;
 
 GtkType                 bonobo_canvas_component_get_type         (void);
-Bonobo_Canvas_Component bonobo_canvas_component_object_create    (BonoboObject                *object);
 BonoboCanvasComponent  *bonobo_canvas_component_construct        (BonoboCanvasComponent       *comp,
-								  Bonobo_Canvas_Component      corba_canvas_comp,
 								  GnomeCanvasItem             *item);
 BonoboCanvasComponent  *bonobo_canvas_component_new              (GnomeCanvasItem             *item);
 GnomeCanvasItem        *bonobo_canvas_component_get_item         (BonoboCanvasComponent       *comp);
@@ -53,12 +52,10 @@ void		        bonobo_canvas_component_grab		 (BonoboCanvasComponent       *comp,
 void		        bonobo_canvas_component_ungrab		 (BonoboCanvasComponent       *comp, guint32 time);
 Bonobo_UIContainer      bonobo_canvas_component_get_ui_container (BonoboCanvasComponent       *comp);
 					  
-POA_Bonobo_Canvas_Component__epv *bonobo_canvas_component_get_epv  (void);
-
 /* This is a helper function for creating a canvas with the root item replaced
  * by a proxy to the client side proxy.
  */
-GnomeCanvas *bonobo_canvas_new (gboolean is_aa,
+GnomeCanvas *bonobo_canvas_new (gboolean                     is_aa,
 				Bonobo_Canvas_ComponentProxy proxy);
 
 END_GNOME_DECLS
