@@ -90,7 +90,8 @@ impl_Bonobo_EventSource_addListenerWithMask (PortableServer_Servant servant,
 	if (event_mask)
 		desc->event_masks = g_strsplit (event_mask, ",", 0);
 
-	event_source->priv->listeners = g_slist_prepend (event_source->priv->listeners, desc);
+	event_source->priv->listeners = g_slist_prepend (
+		event_source->priv->listeners, desc);
 
 	return desc->id;
 }
@@ -100,7 +101,8 @@ impl_Bonobo_EventSource_addListener (PortableServer_Servant servant,
 				     const Bonobo_Listener  l,
 				     CORBA_Environment     *ev)
 {
-	return impl_Bonobo_EventSource_addListenerWithMask (servant, l, NULL, ev);
+	return impl_Bonobo_EventSource_addListenerWithMask (
+		servant, l, NULL, ev);
 }
 
 static void
@@ -108,18 +110,20 @@ impl_Bonobo_EventSource_removeListener (PortableServer_Servant servant,
 					const Bonobo_EventSource_ListenerId id,
 					CORBA_Environment     *ev)
 {
-	BonoboEventSource *event_source;
-	GSList *list;
+	GSList                   *l, *next;
+	BonoboEventSourcePrivate *priv;
 
-	event_source = bonobo_event_source_from_servant (servant);
+	priv = bonobo_event_source_from_servant (servant)->priv;
 
-	for (list = event_source->priv->listeners; list; list = list->next) {
-		ListenerDesc *desc = (ListenerDesc *) list->data;
+	for (l = priv->listeners; l; l = next) {
+		ListenerDesc *desc = l->data;
+
+		next = l->next;
 
 		if (desc->id == id) {
-			event_source->priv->listeners = 
-				g_slist_remove (event_source->priv->listeners,
-						desc);
+			priv->listeners = g_slist_remove_link (
+				priv->listeners, l);
+			g_slist_free_1 (l);
 			desc_free (desc, ev);
 			return;
 		}
@@ -232,21 +236,25 @@ bonobo_event_source_notify_listeners_full (BonoboEventSource *event_source,
 static void
 bonobo_event_source_destroy (GtkObject *object)
 {
-	BonoboEventSource *event_source;
-	GSList            *l;
-	CORBA_Environment  ev;
+	CORBA_Environment         ev;
+	BonoboEventSourcePrivate *priv;
 	
-	event_source = BONOBO_EVENT_SOURCE (object);
+	priv = BONOBO_EVENT_SOURCE (object)->priv;
 
 	CORBA_exception_init (&ev);
+	
+	while (priv->listeners) {
+		ListenerDesc *d = priv->listeners->data;
 
-	for (l = event_source->priv->listeners; l; l = l->next)
-		desc_free (l->data, &ev);
+		priv->listeners = g_slist_remove (
+			priv->listeners, d);
+
+		desc_free (d, &ev);
+	}
 
 	CORBA_exception_free (&ev);
 
-	g_slist_free (event_source->priv->listeners);
-	g_free (event_source->priv);
+	g_free (priv);
 
 	bonobo_event_source_parent_class->destroy (object);
 }
