@@ -247,8 +247,7 @@ bonobo_property_bag_client_persist (Bonobo_PropertyBag       pb,
 
 	g_return_if_fail (ev != NULL);
 	g_return_if_fail (pb != CORBA_OBJECT_NIL);
-	g_return_if_fail (stream != NULL);
-	g_return_if_fail (BONOBO_IS_STREAM (stream));
+	g_return_if_fail (stream != CORBA_OBJECT_NIL);
 
 	persist = Bonobo_Unknown_queryInterface (pb, "IDL:Bonobo/PersistStream:1.0", ev);
 
@@ -289,8 +288,7 @@ bonobo_property_bag_client_depersist (Bonobo_PropertyBag       pb,
 
 	g_return_if_fail (ev != NULL);
 	g_return_if_fail (pb != CORBA_OBJECT_NIL);
-	g_return_if_fail (stream != NULL);
-	g_return_if_fail (BONOBO_IS_STREAM (stream));
+	g_return_if_fail (stream != CORBA_OBJECT_NIL);
 
 	persist = Bonobo_Unknown_queryInterface (
 		pb, "IDL:Bonobo/PersistStream:1.0", ev);
@@ -752,7 +750,7 @@ bonobo_property_bag_client_get_flags (Bonobo_PropertyBag       pb,
 
 #define SEND(pb,name,args,corbat,gt,ansip)									\
 	case CORBA_tk##corbat:											\
-		bonobo_property_bag_client_set_value##gt (pb, name, (CORBA##corbat) va_arg (args, ##ansip), ev);\
+		bonobo_property_bag_client_set_value##gt (pb, name, (CORBA##corbat) va_arg (args, ansip), ev);\
 		break;
 
 /**
@@ -819,7 +817,7 @@ bonobo_property_bag_client_setv (Bonobo_PropertyBag       pb,
 
 #define RECEIVE(pb,name,args,corbat,gt,ansip)					\
 	case CORBA_tk##corbat:							\
-		*((CORBA##corbat *)va_arg (args, ##ansip *)) =			\
+		*((CORBA##corbat *)va_arg (args, ansip *)) =			\
 		    bonobo_property_bag_client_get_value##gt (pb, name, ev);	\
 		break;
 
