@@ -567,7 +567,7 @@ bonobo_property_bag_add_gtk_args (BonoboPropertyBag  *pb,
 {
 	GtkArg  *args, *arg;
 	guint32 *arg_flags;
-	int      nargs = 0;
+	guint    nargs = 0;
 	int      i;
 
 	g_return_if_fail (pb != NULL);
