@@ -617,6 +617,7 @@ impl_xml_set (BonoboUIComponent  *component,
 	Bonobo_UIContainer container;
 	char              *name;
 
+	g_return_if_fail (xml != NULL);
 	g_return_if_fail (BONOBO_IS_UI_COMPONENT (component));
 	container = component->priv->container;
 	g_return_if_fail (container != CORBA_OBJECT_NIL);
@@ -1198,7 +1199,7 @@ impl_get_prop (BonoboUIComponent *component,
 
 	if (ans) {
 		ret = g_strdup (ans);
-		bonobo_ui_node_free_string (ans);
+		CORBA_free (ans);
 	} else
 		ret = NULL;
 
