@@ -79,20 +79,36 @@ impl_Bonobo_UIContainer_setNode (PortableServer_Servant   servant,
 	BonoboUIEngine *engine = get_engine (servant);
 	BonoboUIError   err;
 	BonoboUINode   *node;
+	const CORBA_char *property;
 
 /*	fprintf (stderr, "Merging :\n%s\n", xml);*/
 
 	if (!xml)
 		err = BONOBO_UI_ERROR_BAD_PARAM;
 	else {
-		node = bonobo_ui_node_from_string (xml);
+		if ((property = strrchr (path, '#'))) {
+			char *real_path;
+			real_path = g_strdup (path);
+			real_path [property-path] = 0;
+			property = property + 1; /* Skip the '#' */
+
+			err = bonobo_ui_engine_xml_set_prop (engine,
+							     real_path,
+							     property,
+							     xml,
+							     component_name);
+			g_free (real_path);
+		} else {
+			node = bonobo_ui_node_from_string (xml);
 		
-		if (!node)
-			err = BONOBO_UI_ERROR_INVALID_XML;
-		else
-			err = bonobo_ui_engine_xml_merge_tree (
-				engine, path, node, component_name);
+			if (!node)
+				err = BONOBO_UI_ERROR_INVALID_XML;
+			else
+				err = bonobo_ui_engine_xml_merge_tree (
+								       engine, path, node, component_name);
+		}
 	}
+		
 
 	if (err) {
 		if (err == BONOBO_UI_ERROR_INVALID_PATH)
@@ -114,12 +130,30 @@ impl_Bonobo_UIContainer_getNode (PortableServer_Servant servant,
 {
 	BonoboUIEngine *engine = get_engine (servant);
 	CORBA_char *xml;
-
-	xml = bonobo_ui_engine_xml_get (engine, path, nodeOnly);
-	if (!xml) {
-		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
-				     ex_Bonobo_UIContainer_InvalidPath, NULL);
-		return NULL;
+	const CORBA_char *property;
+	
+	if ((property = strrchr (path, '#'))) {
+		char *real_path;
+		real_path = g_strdup (path);
+		real_path [property-path] = 0;
+		property = property + 1; /* Skip the '#' */
+		
+		xml = bonobo_ui_engine_xml_get_prop (engine, real_path, property);
+		g_free (real_path);
+		
+		if (!xml) {
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
+					     ex_Bonobo_UIContainer_InvalidPath, NULL);
+			return NULL;
+		}
+	} else {
+		xml = bonobo_ui_engine_xml_get (engine, path, nodeOnly);
+	
+		if (!xml) {
+			CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
+					     ex_Bonobo_UIContainer_InvalidPath, NULL);
+			return NULL;
+		}
 	}
 
 	return xml;
