@@ -69,11 +69,6 @@ efs_typehash_clear (EFS *efs)
 		g_hash_table_destroy (efs->i2s_hash);
 		efs->i2s_hash = NULL;
 	}
-
-	if (efs->typefd) {
-		efs_file_close (efs->typefd);
-		efs->typefd = NULL;
-	}
 }
 
 gchar*
@@ -95,6 +90,7 @@ efs_strerror(EFSResult errnum)
 	case EFS_ERR_INVAL:        return "invalid argument";
 	case EFS_ERR_OK:           return "everithing is ok"; 
 	case EFS_ERR_INT:          return "internal error";
+	case EFS_ERR_NOTYPE:       return "no such type";
 	default:                   return "unknown error";
 	}
 }
