@@ -412,7 +412,7 @@ ib1_node_open (EFSNode **node, EFSDir *efs_dir, const char *path,
 		if (!(de->type & EFS_DIR)) return EFS_ERR_NOTDIR;
 		(IB1Dir *)(*node) = g_new0 (IB1Dir, 1);
 		(*node)->efs = (EFS *)efs; 
-		(*node)->mode = EFS_DIR;
+		(*node)->mode = (flags&EFS_RDWR) | EFS_DIR;
 		((IB1Dir *)(*node))->inode = inode;
 		ib1_inode_ref (efs, inode);
 	}
