@@ -4,7 +4,7 @@
 
 #include <gdk/gdkprivate.h>
 #include <gdk/gdkx.h>
-#include <bonobo/bonobo.h>
+#include <bonobo.h>
 
 #define TESTSIZE (1024*1)
 
