@@ -11,6 +11,7 @@
  */
 
 #include "config.h"
+#include <sys/time.h>
 #include <gnome.h>
 #include <bonobo.h>
 #include <liboaf/liboaf.h>
@@ -21,6 +22,178 @@
 
 poptContext ctx;
 
+#define NUM_WIN  1
+#define NUM_FILL 10
+
+static void
+test_nodes_same (BonoboUINode *a,
+		 BonoboUINode *b)
+{
+#if 0
+	BonoboUINode *la, *lb;
+
+	g_assert (bonobo_ui_node_same_attrs (a, b));
+
+	la = bonobo_ui_node_children (a);
+	lb = bonobo_ui_node_children (b);
+
+	if (la || lb)
+		test_nodes_same (la, lb);
+#endif
+}
+
+static void
+print_time (FILE *file, const char *msg,
+	    struct timeval *t1, struct timeval *t2)
+{
+	long usecdiff = t2->tv_usec - t1->tv_usec;
+	long usecdiv = 1000 * 1000;
+
+	fprintf (file, "%s %d:%.6d\n", msg,
+		 (int)((t2->tv_sec - t1->tv_sec) + (usecdiff / usecdiv)),
+		 (int)(usecdiff % usecdiv));
+}
+
+static void
+flush (void)
+{
+	while (gtk_events_pending ())
+		gtk_main_iteration ();
+	gdk_flush ();
+}
+
+static BonoboUIComponent *
+fill_window (BonoboWindow *win, BonoboUINode *ui)
+{
+	BonoboUIContainer *container = bonobo_ui_container_new ();
+	BonoboUIComponent *component = bonobo_ui_component_new ("Foo");
+
+	bonobo_ui_container_set_win (container, win);
+	bonobo_ui_component_set_container (
+		component, BONOBO_OBJREF (container));
+	
+	if (ui)
+		bonobo_ui_component_set_tree (
+			component, "/", ui, NULL);
+
+	return component;
+}
+
+static void
+speed_tests (void)
+{
+	GtkWidget     *wins [NUM_WIN];
+	int            i;
+	struct timeval t1, t2;
+
+#if 0
+	{ /* GtkWindow */
+		g_assert (!gettimeofday (&t1, NULL));
+		{
+			for (i = 0; i < NUM_WIN; i++) {
+				wins [i] = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+				gtk_widget_show (wins [i]);
+			}
+			flush ();
+		}
+		g_assert (!gettimeofday (&t2, NULL));
+
+		print_time (stderr, "Normal GtkWindow create ", &t1, &t2);
+
+		g_assert (!gettimeofday (&t1, NULL));
+		{
+			for (i = 0; i < NUM_WIN; i++)
+				gtk_widget_destroy (wins [i]);
+		
+			flush ();
+		}
+		g_assert (!gettimeofday (&t2, NULL));
+
+		print_time (stderr, "Normal GtkWindow destroy ", &t1, &t2);
+	}
+
+	{ /* BonoboWindow */
+		g_assert (!gettimeofday (&t1, NULL));
+		{
+			for (i = 0; i < NUM_WIN; i++) {
+				wins [i] = bonobo_window_new ("foo", "baa");
+				gtk_widget_show (wins [i]);
+			}
+			flush ();
+		}
+		g_assert (!gettimeofday (&t2, NULL));
+
+		print_time (stderr, "plain BonoboWindow create ", &t1, &t2);
+
+		g_assert (!gettimeofday (&t1, NULL));
+		{
+			for (i = 0; i < NUM_WIN; i++)
+				gtk_widget_destroy (wins [i]);
+		
+			flush ();
+		}
+		g_assert (!gettimeofday (&t2, NULL));
+
+		print_time (stderr, "plain BonoboWindow destroy ", &t1, &t2);
+	}
+#endif
+
+	{ /* BonoboWindow + XML */
+		BonoboUINode *ui;
+		BonoboUIComponent *components [NUM_WIN];
+
+		ui = bonobo_ui_util_new_ui (
+			NULL, "std-ui.xml", ".", "foobar");
+
+		if (!ui)
+			g_warning ("XML Speed tests failed");
+		else {
+
+
+			g_assert (!gettimeofday (&t1, NULL));
+			{
+				for (i = 0; i < NUM_WIN; i++) {
+					wins [i] = bonobo_window_new ("foo", "baa");
+					components [i] = fill_window (BONOBO_WINDOW (wins [i]), ui);
+					gtk_widget_show (wins [i]);
+				}
+				flush ();
+			}
+			g_assert (!gettimeofday (&t2, NULL));
+
+			print_time (stderr, "plain BonoboWindow create ", &t1, &t2);
+
+			g_assert (!gettimeofday (&t1, NULL));
+			{
+				for (i = 0; i < NUM_WIN; i++) {
+					int i2;
+					for (i2 = 0; i2 < NUM_FILL; i2++)
+						bonobo_ui_component_set_tree (
+							components [i], "/", ui, NULL);
+					
+					flush ();
+				}
+			}
+			g_assert (!gettimeofday (&t2, NULL));
+
+			print_time (stderr, "BonoboWindow XML thrash ", &t1, &t2);
+
+			g_assert (!gettimeofday (&t1, NULL));
+			{
+				for (i = 0; i < NUM_WIN; i++)
+					gtk_widget_destroy (wins [i]);
+		
+				flush ();
+			}
+			g_assert (!gettimeofday (&t2, NULL));
+
+			print_time (stderr, "plain BonoboWindow destroy ", &t1, &t2);
+
+			bonobo_ui_node_free (ui);
+		}
+	}
+}
+
 BonoboUIComponent *global_component;
 
 static void
@@ -259,8 +432,8 @@ main (int argc, char **argv)
 					printf ("a [%d] (=%d) != b [%d] (=%d)\n",
 						i, a [i], i, b [i]);
 			}
-		} else
-			printf ("String encode / decode worked\n");
+		} /* else
+		     printf ("String encode / decode worked\n"); */
 
 		g_free (c);
 		g_free (b);
@@ -270,12 +443,20 @@ main (int argc, char **argv)
 		c = bonobo_ui_util_decode_str (b, &err);
 		g_assert (err == FALSE);
 
-		printf ("Encode to '%s' and back to '%s'\n", b, c);
+/*		printf ("Encode to '%s' and back to '%s'\n", b, c); */
 
 		g_free (c);
 		g_free (b);
 	}
 
+	{
+		BonoboUINode *n = bonobo_ui_node_from_string (toola);
+		test_nodes_same (n, n);
+		bonobo_ui_node_free (n);
+	}
+
+	speed_tests ();
+
 	win = BONOBO_WINDOW (bonobo_window_new ("Win", "My Test Application"));
 	container = bonobo_ui_container_new ();
 	bonobo_ui_container_set_win (container, win);
